==> 1.0.0.tar.gz: lib/src/eventPost/createEvent.dart <==
import 'dart:convert';

import 'package:event_analysis_library/src/eventPost/controller/eventController.dart';
import 'package:event_analysis_library/src/shared/model/request/user_identity.dart';
import 'package:event_analysis_library/src/shared/model/sdk_initialization/sdk_initialization.dart';
import 'package:event_analysis_library/src/shared/permission_service.dart';
import 'package:event_analysis_library/src/shared/utils.dart';
import 'package:flutter/cupertino.dart';
import 'package:geolocator/geolocator.dart';
import 'package:permission_handler/permission_handler.dart';

class CreateEvent {
  String? sessionId;
  SdkInitialization? sdkInitialization;
  String productKey;
  EventController? eventController;
  String locale;

  CreateEvent({required this.productKey, required this.locale}){
    this.sessionId = Utils().getSessionId();
    eventController = EventController(this);
  }

  //GET DEVICE METADATA TO SEND ON INITIALIZATION API
  _getDeviceMetaData(Position? location) {
    var data = Utils().getDeviceMeta(sessionId!, location, locale);
    return data;
  }

  //CHECK IF LOCATION IS GRANTED
  //IF GRANTED GET CURRENT LOCATION ELSE GET LAST KNOWN ELSE NULL LOCATION
  //CALL INITIALIZATION API
  _getLocation() async {
    var locationPermission = await Permission.location.status;
    bool isLocationEnabled = await Utils().isLocationEnabled();
    var _locationData;
    if (locationPermission.isGranted) {
      if (isLocationEnabled) {
        _locationData = await Geolocator.getCurrentPosition();
      } else {
        _locationData = await Geolocator.getLastKnownPosition();
      }

      _locationData != null ? await _callInitializationApi(_locationData) : await _callApiWhenLocationNull();
      return;
    }
    await _callApiWhenLocationNull();
    return;
  }

  //CALL POST EVENT API
  postEvent(String eventType, String eventValue, String userId, Offset position){
    var eventJson = Utils().getEventData(eventType, eventValue, userId, sessionId!, position);
    eventController!.eventPost(sdkInitialization!.result.token, sdkInitialization!.result.project_id, eventJson);
  }

  //CALL POST USER IDENTITY API
  userIdentity(String userId){
    var user = UserIdentity(sessionId!, userId).toJson();
    eventController!.userIdentity(sdkInitialization!.result.token, sdkInitialization!.result.project_id, json.encode(user));
  }

  //CHECK IF LOCATION PERMISSION IS GRANTED
  //IF NOT ASK AND CALL GET LOCATION
  initialize() async {
    var location = await Permission.location.status;
    if (location.isGranted) {
      return await _getLocation();
    } else {
      await PermissionService().requestLocationPermission();
      if (location.isGranted) return await _getLocation();
    }
    return await _getLocation();
  }

  //SDK INITIALIZATION CALLBACK
  //GET SDK INITIALIZATION VALUE AFTER SDK INIT API IS CALLED
  initializationSdk(SdkInitialization sdkInit) {
    sdkInitialization = sdkInit;
    print(sdkInitialization!.result.token);
  }

  _callInitializationApi(Position location) async {
    print("CALL INITIALIZATION API");
    var deviceInfo = await _getDeviceMetaData(location);
    await eventController!.initializeSdk(productKey, deviceInfo);
  }

  _callApiWhenLocationNull() async {
    print("CALL INITIALIZATION API WHEN LOCATION NULL");
    var deviceInfo = await _getDeviceMetaData(null);
    await eventController!.initializeSdk(productKey, deviceInfo);
  }
}

==> 1.0.2.tar.gz: lib/src/eventPost/createEvent.dart <==
import 'dart:convert';

import 'package:event_analysis_library/src/eventPost/controller/eventController.dart';
import 'package:event_analysis_library/src/shared/model/request/user_identity.dart';
import 'package:event_analysis_library/src/shared/model/sdk_initialization/sdk_initialization.dart';
import 'package:event_analysis_library/src/shared/permission_service.dart';
import 'package:event_analysis_library/src/shared/utils.dart';
import 'package:flutter/cupertino.dart';
import 'package:geolocator/geolocator.dart';
import 'package:permission_handler/permission_handler.dart';

class CreateEvent {
  String? sessionId;
  SdkInitialization? sdkInitialization;
  String productKey;
  EventController? eventController;
  String locale;

  CreateEvent({required this.productKey, required this.locale}){
    this.sessionId = Utils().getSessionId();
    eventController = EventController(this);
  }

  //GET DEVICE METADATA TO SEND ON INITIALIZATION API
  _getDeviceMetaData(Position? location) {
    var data = Utils().getDeviceMeta(sessionId!, location, locale);
    return data;
  }

  //CHECK IF LOCATION IS GRANTED
  //IF GRANTED GET CURRENT LOCATION ELSE GET LAST KNOWN ELSE NULL LOCATION
  //CALL INITIALIZATION API
  _getLocation() async {
    var locationPermission = await Permission.location.status;
    bool isLocationEnabled = await Utils().isLocationEnabled();
    var _locationData;
    var result;
    if (locationPermission.isGranted) {
      if (isLocationEnabled) {
        _locationData = await Geolocator.getCurrentPosition();
      } else {
        _locationData = await Geolocator.getLastKnownPosition();
      }

      result = _locationData != null ? await _callInitializationApi(_locationData) : await _callApiWhenLocationNull();
      return result;
    }
    result = await _callApiWhenLocationNull();
    return result;
  }

  //CALL POST EVENT API
  postEvent({required String eventType, required String eventValue, required String userId, required Offset position}){
    if(sdkInitialization == null){
      print('Pinewheel not initialized yet');
    }else{
      var eventJson = Utils().getEventData(eventType, eventValue, userId, sessionId!, position);
      eventController!.eventPost(sdkInitialization!.result.token, sdkInitialization!.result.project_id, eventJson);
    }
  }

  //CALL POST USER IDENTITY API
  userIdentity(String userId){
    if(sdkInitialization == null){
      print('Pinewheel not initialized yet');
    }else {
      var user = UserIdentity(sessionId!, userId).toJson();
      eventController!.userIdentity(
          sdkInitialization!.result.token, sdkInitialization!.result.project_id,
          json.encode(user));
    }
  }

  //CHECK IF LOCATION PERMISSION IS GRANTED
  //IF NOT ASK AND CALL GET LOCATION
  initialize() async {
    var location = await Permission.location.status;
    if (location.isGranted) {
      var result =  await _getLocation();
      return result;
    } else {
      await PermissionService().requestLocationPermission();
      if (location.isGranted) {
          var result = await _getLocation();
          return result;
        }
      }
    var result = await _getLocation();
    return result;
  }

  //SDK INITIALIZATION CALLBACK
  //GET SDK INITIALIZATION VALUE AFTER SDK INIT API IS CALLED
  initializationSdk(SdkInitialization sdkInit) {
    sdkInitialization = sdkInit;
  }

  _callInitializationApi(Position location) async {
    print("CALL INITIALIZATION API");
    var deviceInfo = await _getDeviceMetaData(location);
    var result = await eventController!.initializeSdk(productKey, deviceInfo);
    return result;
  }

  _callApiWhenLocationNull() async {
    print("CALL INITIALIZATION API WHEN LOCATION NULL");
    var deviceInfo = await _getDeviceMetaData(null);
    var result = await eventController!.initializeSdk(productKey, deviceInfo);
    return result;
  }
}
